#
# spec file for package python-certbot
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-certbot
Version:        0.30.2
Release:        lp150.6.1
Summary:        ACME client
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/certbot/certbot
Source:         https://files.pythonhosted.org/packages/source/c/certbot/certbot-%{version}.tar.gz
BuildRequires:  %{python_module acme >= 0.29.0}
BuildRequires:  %{python_module configargparse >= 0.9.3}
BuildRequires:  %{python_module configobj}
BuildRequires:  %{python_module cryptography >= 1.2}
BuildRequires:  %{python_module future}
BuildRequires:  %{python_module josepy}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module parsedatetime >= 1.3}
BuildRequires:  %{python_module pyRFC3339}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module zope.component}
BuildRequires:  %{python_module zope.interface}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  python2-typing
Requires:       python-acme >= 0.29.0
Requires:       python-configargparse >= 0.9.3
Requires:       python-configobj
Requires:       python-cryptography >= 1.2
Requires:       python-future
Requires:       python-josepy
Requires:       python-mock
Requires:       python-parsedatetime >= 1.3
Requires:       python-pyRFC3339
Requires:       python-pytz
Requires:       python-setuptools
Requires:       python-zope.component
Requires:       python-zope.interface
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       certbot = %{version}
Obsoletes:      certbot < %{version}
BuildArch:      noarch
%ifpython2
Requires:       python-typing
%endif
%python_subpackages

%description
certbot is a free, automated certificate authority that aims
to lower the barriers to entry for encrypting all HTTP traffic on the internet.

%prep
%setup -q -n certbot-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/certbot
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_exec setup.py test

%post
%python_install_alternative certbot

%postun
%python_uninstall_alternative certbot

%files %{python_files}
%license LICENSE.txt
%doc README.rst
%{python_sitelib}/*
%python_alternative %{_bindir}/certbot

%changelog
* Thu Mar 14 2019 Tomáš Chvátal <tchvatal@suse.com>
- Provide certbot namespace on py2 too to avoid migration conflict
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.30.2:
  * Update the version of setuptools pinned in certbot-auto to 40.6.3 to
    solve installation problems on newer OSes.
  * Always download the pinned version of pip in pipstrap to address breakages
  * Rename old,default.conf to old-and-default.conf to address commas in filenames
    breaking recent versions of pip.
  * Add VIRTUALENV_NO_DOWNLOAD=1 to all calls to virtualenv to address breakages
    from venv downloading the latest pip
  * Added the `update_account` subcommand for account management commands.
* Sat Dec 15 2018 Thomas Bechtold <tbechtold@suse.com>
- update to 0.29.1:
  * The default work and log directories have been changed back
    to /var/lib/letsencrypt and /var/log/letsencrypt respectively.
  * Noninteractive renewals with `certbot renew` (those not started
    from a terminal) now randomly sleep 1-480 seconds before beginning
    work in order to spread out load spikes on the server side.
  * Added External Account Binding support in cli and acme library.
    Command line arguments --eab-kid and --eab-hmac-key added.
  * Private key permissioning changes: Renewal preserves existing group mode
    & gid of previous private key material. Private keys for new
    lineages (i.e. new certs, not renewed) default to 0o600.
  * Update code and dependencies to clean up Resource and Deprecation Warnings.
  * Only depend on imgconverter extension for Sphinx >= 1.6
- update URL
* Fri Nov 30 2018 Jason Craig <os-dev@jacraig.com>
- Add Requires: python-mock, it won't run without it
* Fri Nov 16 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.28.0
  * revoke accepts --cert-name, and doesn't accept both --cert-name
    and --cert-path
* Tue Oct  9 2018 Tomáš Chvátal <tchvatal@suse.com>
- Do not conflict with Certbot as now we provide/obsolete it
* Wed Oct  3 2018 Tomáš Chvátal <tchvatal@suse.com>
- Provide and obsolete certbot main package too to ensure we can
  migrate to the new split setup directly
* Tue Sep 18 2018 Tomáš Chvátal <tchvatal@suse.com>
- Conflict with certbot package to allow easy migration
* Fri Sep 14 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.27.1
  * the documentation can be built using Sphinx 1.6+
* Tue Aug 28 2018 tchvatal@suse.com
- Initial package, split from certbot blob
